Class mfbootcluster
mfbootcluster-class.RdClass mfbootcluster is created from output of function MFClusBoot
Fields
nboot: numeric value specifying number of samplesalpha: numeric value specifying complement of confidence intervalseed: vector of integers specifying seed for pseudo-random number generator usedcompare: vector of character strings naming groups comparedrng: character string naming type of random number generatorstat: matrix matrix with columns observed, median, lower, upper for estimateswhat: character vector naming what was resampled: clusters, units, bothexcludedClusters: character vector naming clusters excluded because of missing treatment(s)call: the call toMFClusBootsample: what is this?All: Field "All" from MFClus call.
See also
Other mf:
mf-class,
mfboot-class,
mfhlboot-class