Class mfclushier
mfclushier-class.RdClass mfclushier is created from output of function MFClusHier
Fields
MFh: output from MFh. A mfhierdata object.MFnest: output from MFnest. A tibble.

mfclushier-class.RdClass mfclushier is created from output of function MFClusHier
MFh: output from MFh. A mfhierdata object.
MFnest: output from MFnest. A tibble.