Skip to contents

Class mfhierdata is created from output of function MFh

Fields

  • coreTbl: data.frame with one row for each unique core level showing values for nx, ny, N, w, u, and median observed response.

  • data: data.frame is the restructured input data used for calculations in MFh and MFnest.

  • compare: character vector naming groups being compared.

  • formula: formula that was called by user.

See also

Author

MF-package