Class mfcluster
mfcluster-class.RdClass mfcluster is created from output of function MFClus
Fields
All: vector with elementsw: Wilcoxon statisticu: Mann-Whitney statisticr: mean riditn1: size of group 1n2: size of group 2mf: mitigated fraction
byCluster: As for All, by clustersexcludedClusters: character vector naming clusters excluded because of missing treatmentcall: the call toMFCluscompare: character vector naming groups compared