Class mfhierdata
mfhierdata-class.RdClass mfhierdata is created from output of function MFh
Fields
coreTbl: data.frame with one row for each unique core level showing values fornx,ny,N,w,u, andmedianobserved response.data: data.frame is the restructured input data used for calculations in MFh and MFnest.compare: character vector naming groups being compared.formula: formula that was called by user.